@@ -73,6 +73,7 @@ def parser(literal_string, ident, sqlserver=False):
     with Whitespace() as engine:
         engine.add_ignore(Literal("--") + restOfLine)
         engine.add_ignore(Literal("#") + restOfLine)
+        engine.add_ignore(Literal("/*") + SkipTo("*/", include=True))
 
         var_name = ~RESERVED + ident
 
@@ -509,6 +510,7 @@ def parser(literal_string, ident, sqlserver=False):
                 | assign("auto_increment", EQ + int_num)
                 | assign("comment", EQ + literal_string)
                 | assign("default character set", EQ + var_name)
+                | assign("default charset", EQ + var_name)
             )
             + Optional(AS.suppress() + infix_notation(query, [])("query"))
         )("create table")
