@@ -37,10 +37,9 @@ from mo_sql_parsing.utils import (
 _size = Optional(LB + int_num("params") + RB)
 _sizes = Optional(LB + delimited_list(int_num("params")) + RB)
 
-
 simple_types = Forward()
 
-BIGINT = Group(keyword("bigint")("op")) / to_json_call
+BIGINT = Group(keyword("bigint")("op") + Optional(_size)+Optional(flag("unsigned"))) / to_json_call
 BOOL = Group(keyword("bool")("op")) / to_json_call
 BOOLEAN = Group(keyword("boolean")("op")) / to_json_call
 DOUBLE = Group(keyword("double")("op")) / to_json_call
@@ -155,7 +154,6 @@ unary_ops = {
 
 
 def get_column_type(expr, var_name, literal_string):
-
     column_definition = Forward()
     column_type = Forward().set_parser_name("column type")
 
